<?php

namespace App\Http\Controllers;

use App\Http\Requests\OrderRequest;
use App\Services\Order\OrderServiceImpl;
use Exception;
use Illuminate\Http\Request;

class OrderController extends Controller
{
    protected OrderServiceImpl $orderServiceImpl;

    public function __construct(OrderServiceImpl $orderServiceImpl)
    {
        $this->orderServiceImpl = $orderServiceImpl;
    }

    public function createOrder(OrderRequest $orderRequest)
    {
        $order = $this->orderServiceImpl->createOrder($orderRequest->validated());

        return response()->json([
            'status' => true,
            'message' => 'Order created successfully!',
            'order' => $order,
        ], 201);
    }

    public function getUserOrders(Request $request)
    {

       try
       {
            $paginate = $request->input('paginate', 10);
            $orders =  $this->orderServiceImpl->getUserOrders($paginate);


            return response()->json(['status' => true, 'success' => $orders]);
       }
    
       catch (Exception $e) {

            return response()->json(['status' => false, 'error' => $e->getMessage()],500);
        }
    }
}
